==> xlniuxdata_gamepay_new-1.4.4-sources.jar: com/xunlei/gamepay/vo/ChargeMonthEnd.java <==
package com.xunlei.gamepay.vo;

import com.xunlei.common.util.Extendable;


public class ChargeMonthEnd {
	private long seqid;
	private String balancemonth;
	private String gameid;
	private double testamt; //测试金额
	private int testordernums; //测试订单数量
	private double incomeamt; //营收金额
	private int incomeordernums; //测试订单数量
	private double allamt; //总金额
	private double giftamt; //返利金额
	private String remark;
	private double vouchersMoney;
	private double notSuccessMoney;

	@Extendable
	private String frommonth;
	@Extendable
	private String tomonth;
	@Extendable
	private String dsname;
    @Extendable
    private String gameIdLike;
    @Extendable
    private double userpayamt; //用户支付金额;userpayamt=incomeamt-giftamt-vouchersMoney
	private double incomeamtNiux;//牛X营收。对混服游戏此值可小于incomeamt。
	private double incomeamtAgent;//混服营收。对混服游戏此值不为空。

	public double getIncomeamtAgent() {
		return incomeamtAgent;
	}

	public void setIncomeamtAgent(double incomeamtAgent) {
		this.incomeamtAgent = incomeamtAgent;
	}

	public double getIncomeamtNiux() {
		return incomeamtNiux;
	}

	public void setIncomeamtNiux(double incomeamtNiux) {
		this.incomeamtNiux = incomeamtNiux;
	}


    public String getGameIdLike() {
        return gameIdLike;
    }

    public void setGameIdLike(String gameIdLike) {
        this.gameIdLike = gameIdLike;
    }
	public String getFrommonth() {
		return frommonth;
	}
	public void setFrommonth(String frommonth) {
		this.frommonth = frommonth;
	}
	public String getTomonth() {
		return tomonth;
	}
	public void setTomonth(String tomonth) {
		this.tomonth = tomonth;
	}
	public String getDsname() {
		return dsname;
	}
	public void setDsname(String dsname) {
		this.dsname = dsname;
	}
	public long getSeqid() {
		return seqid;
	}
	public void setSeqid(long seqid) {
		this.seqid = seqid;
	}
	
	public String getBalancemonth() {
		return balancemonth;
	}
	public void setBalancemonth(String balancemonth) {
		this.balancemonth = balancemonth;
	}
	public String getGameid() {
		return gameid;
	}
	public void setGameid(String gameid) {
		this.gameid = gameid;
	}
	public double getTestamt() {
		return testamt;
	}
	public void setTestamt(double testamt) {
		this.testamt = testamt;
	}
	public int getTestordernums() {
		return testordernums;
	}
	public void setTestordernums(int testordernums) {
		this.testordernums = testordernums;
	}
	public double getIncomeamt() {
		return incomeamt;
	}
	public void setIncomeamt(double incomeamt) {
		this.incomeamt = incomeamt;
	}
	public int getIncomeordernums() {
		return incomeordernums;
	}
	public void setIncomeordernums(int incomeordernums) {
		this.incomeordernums = incomeordernums;
	}
	public double getAllamt() {
		return allamt;
	}
	public void setAllamt(double allamt) {
		this.allamt = allamt;
	}
	
	public double getGiftamt() {
		return giftamt;
	}
	public void setGiftamt(double giftamt) {
		this.giftamt = giftamt;
	}
	public String getRemark() {
		return remark;
	}
	public void setRemark(String remark) {
		this.remark = remark;
	}	
	public double getVouchersMoney() {
		return vouchersMoney;
	}
	public void setVouchersMoney(double vouchersMoney) {
		this.vouchersMoney = vouchersMoney;
	}
	public double getNotSuccessMoney() {
		return notSuccessMoney;
	}
	public void setNotSuccessMoney(double notSuccessMoney) {
		this.notSuccessMoney = notSuccessMoney;
	}

    public double getUserpayamt(){
        return incomeamt-giftamt-vouchersMoney;
    }

    public void setUserpayamt(double userpayamt){
        this.userpayamt = userpayamt;
    }
}

==> xlniuxdata_gamepay_new-1.4.13-sources.jar: com/xunlei/gamepay/vo/ChargeMonthEnd.java <==
package com.xunlei.gamepay.vo;

import java.math.BigDecimal;

import com.xunlei.common.util.Extendable;


public class ChargeMonthEnd {
	private long seqid;
	private String balancemonth;
	private String gameid;
	private double testamt; //测试金额
	private int testordernums; //测试订单数量
	private double incomeamt; //营收金额
	private int incomeordernums; //测试订单数量
	private double allamt; //总金额
	private double giftamt; //返利金额
	private String remark;
	private double vouchersMoney;
	private double notSuccessMoney;

	@Extendable
	private String frommonth;
	@Extendable
	private String tomonth;
	@Extendable
	private String dsname;
    @Extendable
    private String gameIdLike;
    @Extendable
    private double userpayamt; //用户支付金额;userpayamt=incomeamt-giftamt-vouchersMoney
	private double incomeamtNiux;//牛X营收。对混服游戏此值可小于incomeamt。
	private double incomeamtAgent;//混服营收。对混服游戏此值不为空。
    @Extendable
    private String rate; //分成比例
    @Extendable
    private BigDecimal total;
    @Extendable
    private BigDecimal secondprincipal;
    @Extendable
    private BigDecimal firstprincipal;
    @Extendable
    private Integer clientType; //客户端类型
    @Extendable
	private String gameidbytuijian;

	public String getGameidbytuijian() {
		return gameidbytuijian;
	}

	public void setGameidbytuijian(String gameidbytuijian) {
		this.gameidbytuijian = gameidbytuijian;
	}

	public Integer getClientType() {
		return clientType;
	}

	public void setClientType(Integer clientType) {
		this.clientType = clientType;
	}

	public BigDecimal getTotal() {
		return total;
	}

	public void setTotal(BigDecimal total) {
		this.total = total;
	}

	public BigDecimal getSecondprincipal() {
		return secondprincipal;
	}

	public void setSecondprincipal(BigDecimal secondprincipal) {
		this.secondprincipal = secondprincipal;
	}

	public BigDecimal getFirstprincipal() {
		return firstprincipal;
	}

	public void setFirstprincipal(BigDecimal firstprincipal) {
		this.firstprincipal = firstprincipal;
	}

	public String getRate() {
		return rate;
	}

	public void setRate(String rate) {
		this.rate = rate;
	}

	public double getIncomeamtAgent() {
		return incomeamtAgent;
	}

	public void setIncomeamtAgent(double incomeamtAgent) {
		this.incomeamtAgent = incomeamtAgent;
	}

	public double getIncomeamtNiux() {
		return incomeamtNiux;
	}

	public void setIncomeamtNiux(double incomeamtNiux) {
		this.incomeamtNiux = incomeamtNiux;
	}


    public String getGameIdLike() {
        return gameIdLike;
    }

    public void setGameIdLike(String gameIdLike) {
        this.gameIdLike = gameIdLike;
    }
	public String getFrommonth() {
		return frommonth;
	}
	public void setFrommonth(String frommonth) {
		this.frommonth = frommonth;
	}
	public String getTomonth() {
		return tomonth;
	}
	public void setTomonth(String tomonth) {
		this.tomonth = tomonth;
	}
	public String getDsname() {
		return dsname;
	}
	public void setDsname(String dsname) {
		this.dsname = dsname;
	}
	public long getSeqid() {
		return seqid;
	}
	public void setSeqid(long seqid) {
		this.seqid = seqid;
	}
	
	public String getBalancemonth() {
		return balancemonth;
	}
	public void setBalancemonth(String balancemonth) {
		this.balancemonth = balancemonth;
	}
	public String getGameid() {
		return gameid;
	}
	public void setGameid(String gameid) {
		this.gameid = gameid;
	}
	public double getTestamt() {
		return testamt;
	}
	public void setTestamt(double testamt) {
		this.testamt = testamt;
	}
	public int getTestordernums() {
		return testordernums;
	}
	public void setTestordernums(int testordernums) {
		this.testordernums = testordernums;
	}
	public double getIncomeamt() {
		return incomeamt;
	}
	public void setIncomeamt(double incomeamt) {
		this.incomeamt = incomeamt;
	}
	public int getIncomeordernums() {
		return incomeordernums;
	}
	public void setIncomeordernums(int incomeordernums) {
		this.incomeordernums = incomeordernums;
	}
	public double getAllamt() {
		return allamt;
	}
	public void setAllamt(double allamt) {
		this.allamt = allamt;
	}
	
	public double getGiftamt() {
		return giftamt;
	}
	public void setGiftamt(double giftamt) {
		this.giftamt = giftamt;
	}
	public String getRemark() {
		return remark;
	}
	public void setRemark(String remark) {
		this.remark = remark;
	}	
	public double getVouchersMoney() {
		return vouchersMoney;
	}
	public void setVouchersMoney(double vouchersMoney) {
		this.vouchersMoney = vouchersMoney;
	}
	public double getNotSuccessMoney() {
		return notSuccessMoney;
	}
	public void setNotSuccessMoney(double notSuccessMoney) {
		this.notSuccessMoney = notSuccessMoney;
	}

    public double getUserpayamt(){
        return incomeamt-giftamt-vouchersMoney;
    }

    public void setUserpayamt(double userpayamt){
        this.userpayamt = userpayamt;
    }
}
